@@ -266,7 +266,8 @@ async def run_prompt(device: tuple[int, int, int],
 
                     await asyncio.sleep(0.2)
 
-                stdout = stdout[1 + len(prompt_enc):]
+                # stdout = stdout[1 + len(prompt_enc):]
+                stdout = stdout[len(prompt_enc):]
                 stderr = b''
 
                 # return left-overs from stdout as buf
@@ -323,7 +324,8 @@ async def run_prompt(device: tuple[int, int, int],
                     await asyncio.sleep(0.2)
             else:
                 stdout, stderr = await proc.communicate()
-                stdout = stdout[1 + len(prompt_enc):]
+                # stdout = stdout[1 + len(prompt_enc):]
+                stdout = stdout[len(prompt_enc):]
 
             if streaming:
                 if not stopped:
